builder property
A function to build the widget based on the current datetime (required).
Implementation
final DateTimeLoopWidgetBuilder builder;
A function to build the widget based on the current datetime (required).
final DateTimeLoopWidgetBuilder builder;