controller property

DateTimeLoopController? controller
final

An optional custom controller to use for datetime updates. If provided, timeUnit and triggerOnStateChange (for creation) are ignored, but triggerOnStateChange still controls immediate triggers on widget state changes. This allows users to manage the controller externally, e.g., for pause/resume functionality.

Implementation

final DateTimeLoopController? controller;