triggerOnStateChange property

bool triggerOnStateChange
final

Whether to trigger an initial build immediately upon widget creation or state change, even if the elapsed time based on timeUnit hasn't passed yet. If set to false, the initial build will happen at the first change in system time that aligns with the specified timeUnit. (default: true).

Implementation

final bool triggerOnStateChange;