getNow property
A function to provide the current DateTime. Defaults to DateTime.now. This can be overridden for testing or simulation purposes to mock the system time. If provided, it is used for the initial data and passed to the internal controller if created.
Implementation
final DateTime Function()? getNow;